@@ -80,7 +80,8 @@ function displayResults (results) {
   } else {
     var noResultsText = search_results.getAttribute('data-no-results-text');
     if (!noResultsText) {
-      noResultsText = "Mi dispiace, ma non riesco a trovare quello che sti cercando.";
+      //loc_obj is in theme-loc-**.js
+      noResultsText = loc_obj.search_page_no_results;
     }
     search_results.insertAdjacentHTML('beforeend', '<p>' + noResultsText + '</p>');
   }
